#!/usr/bin/env python
# -*- coding: utf-8 -*-

import urllib2
import urlparse

class GithubStatus(object):

	def __init__(self, base_url='https://status.github.com/api/'):

		self.base_url = base_url
		self.opener = urllib2.build_opener()
		self.opener.addheaders.append(('Content-Type', 'application/json'))
		self.opener.addheaders.append(('User-agent', 'whadup - python wrapper \
		around status.github.com (github.com/mrsmn/whadup)'))

	def status(self):
		url = urlparse.urljoin(self.base_url, 'status.json')
		response = self.opener.open(url).read()
		return response

	def lastmessage(self):
		url = urlparse.urljoin(self.base_url, 'last-message.json')
		response = self.opener.open(url).read()
		return response

	def messages(self):
		url = urlparse.urljoin(self.base_url, 'messages.json')
		response = self.opener.open(url).read()
		return response



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from distutils.core import setup

setup(
	name='whadup',
	version='0.1.1',
	url='https://github.com/mrsmn/whadup',
	download_url='https://github.com/mrsmn/whadup/archive/master.zip',
	author='Martin Simon',
	author_email='me@martinsimon.me',
	license='Apache v2.0 License',
	packages=['whadup'],
	description='A python wrapper around status.github.com',
	long_description=file('README.md','r').read(),
	keywords=['Github', 'Github status', 'API', 'wrapper'],
)